==> librenms-25.9.1v0.tgz: librenms/lang/zh-TW/wireless.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Wireless Sensors Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used to translate names and units of wireless sensors
    |
    */

    'title' => '無線網路',
    'ap-count' => [
        'short' => 'AP 數量',
        'long' => 'AP 數量',
        'unit' => '',
    ],
    'clients' => [
        'short' => '用戶端',
        'long' => '用戶端數量',
        'unit' => '',
    ],
    'capacity' => [
        'short' => '容量',
        'long' => '容量',
        'unit' => '%',
    ],
    'ccq' => [
        'short' => 'CCQ',
        'long' => '客戶端連線品質',
        'unit' => '%',
    ],
    'errors' => [
        'short' => '錯誤',
        'long' => '錯誤數量',
        'unit' => '',
    ],
    'error-ratio' => [
        'short' => '錯誤率',
        'long' => '位元/封包錯誤率',
        'unit' => '%',
    ],
    'error-rate' => [
        'short' => 'BER',
        'long' => '位元錯誤率',
        'unit' => 'bps',
    ],
    'frequency' => [
        'short' => '頻率',
        'long' => '頻率',
        'unit' => 'MHz',
    ],
    'distance' => [
        'short' => '距離',
        'long' => '距離',
        'unit' => 'm',
    ],
    'mse' => [
        'short' => 'MSE',
        'long' => '平均誤差',
        'unit' => 'dB',
    ],
    'noise-floor' => [
        'short' => '背景雜訊',
        'long' => '背景雜訊',
        'unit' => 'dBm',
    ],
    'power' => [
        'short' => '電力/訊號',
        'long' => 'TX/RX 電力或訊號',
        'unit' => 'dBm',
    ],
    'quality' => [
        'short' => '品質',
        'long' => '品質',
        'unit' => '%',
    ],
    'rate' => [
        'short' => '傳送率',
        'long' => 'TX/RX 傳送率',
        'unit' => 'bps',
    ],
    'rssi' => [
        'short' => 'RSSI',
        'long' => '接收訊號強度指標',
        'unit' => 'dBm',
    ],
    'snr' => [
        'short' => 'SNR',
        'long' => '訊號噪訊比',
        'unit' => 'dB',
    ],
    'ssr' => [
        'short' => 'SSR',
        'long' => '訊號強度比',
        'unit' => 'dB',
    ],
    'utilization' => [
        'short' => '使用率',
        'long' => '使用率',
        'unit' => '%',
    ],
    'xpi' => [
        'short' => 'XPI',
        'long' => '交互極化干擾',
        'unit' => 'dB',
    ],

];

==> librenms-26.1.1v0.tgz: librenms/lang/zh-TW/wireless.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Wireless Sensors Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used to translate names and units of wireless sensors
    |
    */

    'title' => '無線網路',
    'ap-count' => [
        'short' => 'APs',
        'long' => 'AP 數量',
        'unit' => '',
    ],
    'clients' => [
        'short' => '用戶端',
        'long' => '用戶端數量',
        'unit' => '',
    ],
    'capacity' => [
        'short' => '容量',
        'long' => '容量',
        'unit' => '%',
    ],
    'ccq' => [
        'short' => 'CCQ',
        'long' => '用戶端連線品質',
        'unit' => '%',
    ],
    'errors' => [
        'short' => '錯誤',
        'long' => '錯誤計數',
        'unit' => '',
    ],
    'error-ratio' => [
        'short' => '錯誤比例',
        'long' => '位元/封包錯誤比例',
        'unit' => '%',
    ],
    'error-rate' => [
        'short' => 'BER',
        'long' => '位元錯誤率',
        'unit' => 'bps',
    ],
    'frequency' => [
        'short' => '頻率',
        'long' => '頻率',
        'unit' => 'MHz',
    ],
    'distance' => [
        'short' => '距離',
        'long' => '距離',
        'unit' => 'm',
    ],
    'mse' => [
        'short' => 'MSE',
        'long' => '均方誤差',
        'unit' => 'dB',
    ],
    'noise-floor' => [
        'short' => '底噪',
        'long' => '底噪',
        'unit' => 'dBm',
    ],
    'power' => [
        'short' => '功率/訊號',
        'long' => 'TX/RX 功率或訊號',
        'unit' => 'dBm',
    ],
    'quality' => [
        'short' => '品質',
        'long' => '品質',
        'unit' => '%',
    ],
    'rate' => [
        'short' => '傳送率',
        'long' => 'TX/RX 傳送率',
        'unit' => 'bps',
    ],
    'rssi' => [
        'short' => 'RSSI',
        'long' => '接收訊號強度指標',
        'unit' => 'dBm',
    ],
    'snr' => [
        'short' => 'SNR',
        'long' => '訊號噪訊比',
        'unit' => 'dB',
    ],
    'sinr' => [
        'short' => 'SINR',
        'long' => '訊號對干擾加噪訊比',
        'unit' => 'dB',
    ],
    'rsrq' => [
        'short' => 'RSRQ',
        'long' => '參考訊號接收品質',
        'unit' => 'dB',
    ],
    'rsrp' => [
        'short' => 'RSRP',
        'long' => '參考訊號接收功率',
        'unit' => 'dBm',
    ],
    'ssr' => [
        'short' => 'SSR',
        'long' => '訊號強度比',
        'unit' => 'dB',
    ],
    'utilization' => [
        'short' => '使用率',
        'long' => '使用率',
        'unit' => '%',
    ],
    'xpi' => [
        'short' => 'XPI',
        'long' => '交互極化干擾',
        'unit' => 'dB',
    ],
    'cell' => [
        'short' => '細胞',
        'long' => '細胞',
        'unit' => '',
    ],
    'channel' => [
        'short' => '頻道',
        'long' => '頻道',
        'unit' => '',
    ],
];
